==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/zh_CN.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "相册",
    "There was a problem reading files from this album" : "从相册中读文件时出现了一个问题",
    "Aborting preview. Could not find the file" : "预览异常，无法找到文件。",
    "Could not move \"{file}\", target exists" : "不能移动 \"{file}\"，目标已存在。",
    "Could not move \"{file}\"" : "不能移动 \"{file}\"",
    "No compatible server found at {remote}" : "在 {remote} 没有找到兼容的服务器",
    "Invalid server url" : "无效的服务器链接 url",
    "Gallery view" : "查看相册",
    "Could not load the description" : "无法载入描述",
    "Could not load the description: " : "无法载入描述",
    "Copyright" : "版权",
    "Could not load the copyright notice: " : "无法载入版权信息",
    "Copyright notice" : "版权信息",
    "Link to copyright document" : "版权信息链接",
    "This application may not work properly on your browser." : "该应用可能无法在您的浏览器内正常运行",
    "For an improved experience, please install one of the following alternatives" : "为了更好地使用体验，请使用以下推荐的浏览器",
    "Your browser is not supported!" : "您的浏览器对此不支持！",
    "please install one of the following alternatives" : "请使用推荐的浏览器",
    "Album cannot be shown" : "相册无法显示",
    "No media files found" : "未找到媒体文件",
    "Upload pictures in the files app to display them here" : "上传图片文件后您可以在这里查看它们",
    "Upload new files via drag and drop or by using the [+] button above" : "通过拖放或使用上面的 [+] 按钮上传新文件",
    "Configuration error" : "配置错误",
    "New" : "新建",
    "Hide Album" : "隐藏专辑",
    "Could not hide album" : "不能隐藏专辑",
    "Error loading slideshow template" : "加载幻灯片模板错误",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>错误!</strong> 此文件无法生成预览。<br>请进入下一张幻灯片，我们将从幻灯片中删除此图像",
    "Next" : "下一个",
    "Play" : "播放",
    "Pause" : "暂停",
    "Previous" : "上一个",
    "Close" : "关闭",
    "Download" : "下载",
    "Toggle background" : "切换背景",
    "Delete" : "删除",
    "Could not create file \"{file}\" because it already exists" : "不能创建文件 \"{file}\" ，因为它已经存在",
    "Could not create file \"{file}\"" : "不能创建文件 \"{file}\"",
    "\"{name}\" is an invalid file name." : "“{name}”是一个无效的文件名。",
    "File name cannot be empty." : "文件名不能为空。",
    "Upload" : "上传",
    "Error" : "错误",
    "Error while sharing" : "共享时出错",
    "Error while unsharing" : "取消共享时出错",
    "Error while changing permissions" : "修改权限时出错",
    "Shared with you and the group {group} by {owner}" : "{owner} 共享给您及 {group} 组",
    "Shared with you by {owner}" : "{owner} 与您共享",
    "Share with users or groups …" : "分享给其他用户或组 ...",
    "Share with users, groups or remote users …" : "分享给其他用户、组或远程用户 ...",
    "Share" : "共享",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "使用 username@example.com/cloud 格式，其他服务器上联盟云的用户共享",
    "Share link" : "分享链接",
    "The public link will expire no later than {days} days after it is created" : "这个共享链接将在创建后 {days} 天失效",
    "Link" : "链接",
    "Password protect" : "密码保护",
    "Password" : "密码",
    "Choose a password for the public link" : "为共享链接设置密码",
    "Allow editing" : "允许编辑",
    "Email link to person" : "发送链接到个人",
    "Send" : "发送",
    "Set expiration date" : "设置过期日期",
    "Expiration" : "过期",
    "Expiration date" : "过期日期",
    "This list is maybe truncated - please refine your search term to see more results." : "此列表可能会被删减 - 请细化您的搜索字词以查看更多结果。",
    "No users or groups found for {search}" : "没有找到 {search} 用户或组",
    "No users found for {search}" : "没有找到 {search} 用户",
    "An error occured. Please try again" : "发生了一个错误请重新尝试",
    "Adding user..." : "添加用户中...",
    "group" : "群组",
    "remote" : "远程",
    "Resharing is not allowed" : "不允许二次共享",
    "Error while retrieving shares" : "检索共享出错",
    "Unshare" : "取消共享",
    "notify by email" : "以邮件通知",
    "can share" : "可共享",
    "can edit" : "可编辑",
    "access control" : "访问控制",
    "create" : "创建",
    "change" : "更改",
    "delete" : "删除",
    "Password protected" : "密码已受保护",
    "Error unsetting expiration date" : "取消设置过期日期时出错",
    "Error setting expiration date" : "设置过期日期时出错",
    "Sending ..." : "正在发送...",
    "Email sent" : "邮件已发送",
    "Warning" : "警告",
    "This share is password-protected" : "这是一个密码保护的共享",
    "The password is wrong. Try again." : "用户名或密码错误！请重试",
    "Sort by date" : "按日期排序",
    "Sort by name" : "按名称排序",
    "Cancel upload" : "取消上传",
    "Album information" : "专辑信息",
    "File list" : "文件列表",
    "Sorry, this file could not be found." : "抱歉，无法找到该文件。",
    "Reasons might be:" : "可能原因是：",
    "the wrong file ID was provided" : "文件ID错误",
    "the file was removed" : "文件已移除",
    "the file is corrupt" : "文件已损坏",
    "the encryption key is missing" : "加密密钥丢失",
    "Here is the error message returned by the server: " : "下面是服务器返回的错误信息：",
    "For more information, please contact your friendly Nextcloud administrator." : "需要更多得信息，请联系您的Nextcloud管理员。",
    "Sorry, but the server could not fulfill your request." : "抱歉，服务器无法完成您的请求。",
    "Possible reasons for the problem:" : "可能的原因：",
    "a conflicting app was installed" : "已安装了一个会引发冲突的应用",
    "a required component is missing or was disconnected" : "必要的部件丢失，或者与服务器的连接已断开",
    "the filesystem is not readable" : "该文件无法打开",
    "For more information, please contact your friendly ownCloud administrator." : "欲了解更多信息，请联系您的熟悉的 ownCloud 管理员。",
    "Sorry, this link doesn't seem to work anymore." : "抱歉，此链接已失效",
    "the item was removed" : "此项已移除",
    "the link has expired" : "链接已过期",
    "sharing is disabled" : "共享已禁用",
    "For more information, please ask the person who has sent you this link." : "欲知详情，请联系共享链接给你的人。",
    "Add to your Nextcloud" : "添加到您的Nextcloud",
    "Picture view" : "查看图片"
},
"nplurals=1; plural=0;");

==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/zh_CN.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "相册",
    "There was a problem reading files from this album" : "从相册中读文件时出现了一个问题",
    "Aborting preview. Could not find the file" : "预览异常，无法找到文件。",
    "Could not move \"{file}\", target exists" : "不能移动 \"{file}\"，目标已存在。",
    "Could not move \"{file}\"" : "不能移动 \"{file}\"",
    "No compatible server found at {remote}" : "在 {remote} 没有找到兼容的服务器",
    "Invalid server url" : "无效的服务器链接 url",
    "Could not load the description" : "无法载入描述",
    "Could not load the description: " : "无法载入描述",
    "Copyright" : "版权",
    "Could not load the copyright notice: " : "无法载入版权信息",
    "Copyright notice" : "版权信息",
    "Link to copyright document" : "版权信息链接",
    "This application may not work properly on your browser." : "该应用可能无法在您的浏览器内正常运行",
    "For an improved experience, please install one of the following alternatives" : "为了更好地使用体验，请使用以下推荐的浏览器",
    "Your browser is not supported!" : "您的浏览器对此不支持！",
    "please install one of the following alternatives" : "请使用推荐的浏览器",
    "Album cannot be shown" : "相册无法显示",
    "No media files found" : "未找到媒体文件",
    "Upload pictures in the Files app to display them here" : "将图片上传至",
    "Upload new files via drag and drop or by using the [+] button above" : "通过拖放或使用上面的 [+] 按钮上传新文件",
    "Configuration error" : "配置错误",
    "New" : "新建",
    "Hide Album" : "隐藏专辑",
    "Could not hide album" : "不能隐藏专辑",
    "Error loading slideshow template" : "加载幻灯片模板错误",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>错误!</strong> 此文件无法生成预览。<br>请进入下一张幻灯片，我们将从幻灯片中删除此图像",
    "Next" : "下一个",
    "Play" : "播放",
    "Pause" : "暂停",
    "Previous" : "上一个",
    "Close" : "关闭",
    "Download" : "下载",
    "Toggle background" : "切换背景",
    "Delete" : "删除",
    "Could not create file \"{file}\" because it already exists" : "不能创建文件 \"{file}\" ，因为它已经存在",
    "Could not create file \"{file}\"" : "不能创建文件 \"{file}\"",
    "\"{name}\" is an invalid file name." : "“{name}”是一个无效的文件名。",
    "File name cannot be empty." : "文件名不能为空。",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" 不是允许的文件类型",
    "Upload" : "上传",
    "Error" : "错误",
    "Error while sharing" : "共享时出错",
    "Error while unsharing" : "取消共享时出错",
    "Error while changing permissions" : "修改权限时出错",
    "Shared with you and the group {group} by {owner}" : "{owner} 共享给您及 {group} 组",
    "Shared with you by {owner}" : "{owner} 与您共享",
    "Share with users or groups …" : "分享给其他用户或组 ...",
    "Share with users, groups or remote users …" : "分享给其他用户、组或远程用户 ...",
    "Share" : "共享",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "使用 username@example.com/cloud 格式，其他服务器上联盟云的用户共享",
    "Share link" : "分享链接",
    "The public link will expire no later than {days} days after it is created" : "这个共享链接将在创建后 {days} 天失效",
    "Link" : "链接",
    "Password protect" : "密码保护",
    "Password" : "密码",
    "Choose a password for the public link" : "为共享链接设置密码",
    "Allow editing" : "允许编辑",
    "Email link to person" : "发送链接到个人",
    "Send" : "发送",
    "Set expiration date" : "设置过期日期",
    "Expiration" : "过期",
    "Expiration date" : "过期日期",
    "This list is maybe truncated - please refine your search term to see more results." : "此列表可能会被删减 - 请细化您的搜索字词以查看更多结果。",
    "No users or groups found for {search}" : "没有找到 {search} 用户或组",
    "No users found for {search}" : "没有找到 {search} 用户",
    "An error occured. Please try again" : "发生了一个错误请重新尝试",
    "Adding user..." : "添加用户中...",
    "group" : "群组",
    "remote" : "远程",
    "Resharing is not allowed" : "不允许二次共享",
    "Error while retrieving shares" : "检索共享出错",
    "Unshare" : "取消共享",
    "notify by email" : "以邮件通知",
    "can share" : "可共享",
    "can edit" : "可编辑",
    "access control" : "访问控制",
    "create" : "创建",
    "change" : "更改",
    "delete" : "删除",
    "Password protected" : "密码已受保护",
    "Error unsetting expiration date" : "取消设置过期日期时出错",
    "Error setting expiration date" : "设置过期日期时出错",
    "Sending ..." : "正在发送...",
    "Email sent" : "邮件已发送",
    "Warning" : "警告",
    "This share is password-protected" : "这是一个密码保护的共享",
    "The password is wrong. Try again." : "用户名或密码错误！请重试",
    "Sort by date" : "按日期排序",
    "Sort by name" : "按名称排序",
    "Cancel upload" : "取消上传",
    "Album information" : "专辑信息",
    "File list" : "文件列表",
    "Sorry, this file could not be found." : "抱歉，无法找到该文件。",
    "Reasons might be:" : "可能原因是：",
    "the wrong file ID was provided" : "文件ID错误",
    "the file was removed" : "文件已移除",
    "the file is corrupt" : "文件已损坏",
    "the encryption key is missing" : "加密密钥丢失",
    "Here is the error message returned by the server: " : "下面是服务器返回的错误信息：",
    "For more information, please contact your friendly Nextcloud administrator." : "需要更多得信息，请联系您的Nextcloud管理员。",
    "Sorry, but the server could not fulfill your request." : "抱歉，服务器无法完成您的请求。",
    "Possible reasons for the problem:" : "可能的原因：",
    "a conflicting app was installed" : "已安装了一个会引发冲突的应用",
    "a required component is missing or was disconnected" : "必要的部件丢失，或者与服务器的连接已断开",
    "the filesystem is not readable" : "该文件无法打开",
    "Sorry, this link doesn't seem to work anymore." : "抱歉，此链接已失效",
    "the item was removed" : "此项已移除",
    "the link has expired" : "链接已过期",
    "sharing is disabled" : "共享已禁用",
    "For more information, please ask the person who has sent you this link." : "欲知详情，请联系共享链接给你的人。",
    "Add to your Nextcloud" : "添加到您的Nextcloud",
    "Picture view" : "查看图片",
    "Gallery view" : "查看相册"
},
"nplurals=1; plural=0;");
